=head1 NAME

Slapd::Backend::Proxy::Store - base class for all store classes

=cut

package Slapd::Backend::Proxy::Store;

use utf8;
use strict;
use warnings;
use base 'Class::Accessor::Lvalue::Fast';

use Slapd::Backend::Constant;

=head1 PUBLIC METHODS

=over

=item B<new>( @options )

Purpose:
  * Constructor

Arguments:
  * List - options, passed to _init()

Returns:
  * Slapd::Backend::Proxy::Store::Base object

=cut

sub new
{
	my $class = shift;
	my $self = bless {}, $class;
	$self->_init( @_ );
	return $self;
}

=item B<save>( @entries )

Purpose:
  * Save entries to disk

Arguments:
  * List - entries

Returns:
  * None

=cut

sub save { die "Abstract" }

=item B<entry>( $dn )

Purpose:
  * Get entry

Arguments:
  * Scalar - dn

Returns:
  * Net::LDAP::Entry

=cut

sub entry
{
	my( $self, $dn ) = @_;
	my @entries = $self->entries( $dn, LDAP_SCOPE_BASE );
	return shift @entries;
}

=item B<entries>( $base, $scope )

Purpose:
  * Get entries

Arguments:
  * Scalar - base
  * Scalar - scope

Returns:
  * List of Net::LDAP::Entry

=cut

sub entries { die "Abstract" }

=back

=head1 PROTECTED METHODS

=over

=item B<_init>( @options )

Purpose:
  * Initialization

Arguments:
  * List - options

Returns:
  * None

=cut

sub _init { die "Abstract" }

=back

=cut

1;

=head1 SEE ALSO

L<Slapd::Backend::Proxy>

=head1 AUTHOR

Aleksey Mashanov <aleksey.mashanov@gmail.com>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut
